@@ -1,6 +1,6 @@
 package Text::CSV::Pivot;
 
-$Text::CSV::Pivot::VERSION   = '0.07';
+$Text::CSV::Pivot::VERSION   = '0.08';
 $Text::CSV::Pivot::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,10 +9,11 @@ Text::CSV::Pivot - Transform CSV file into Pivot Table format.
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
+use strict; use warnings;
 use 5.008;
 use Text::CSV;
 use File::Basename;
@@ -162,7 +163,7 @@ In case, we would want to skip "Year" column then the following code:
                             col_value_idx => 2,
                             col_skip_idx  => [3] })->transform;
 
-You should get the result as below:
+You should get the result in C<sample.pivot.csv> as below:
 
     +----------------+-----------+---------+----------+-------+-------+
     | Student        | Geography | History | Language | Maths | Music |
@@ -187,6 +188,21 @@ distribution called C<csv-pivot>.
          -s, --s, -col-skip-idx,  --col-skip-idx=s   comma separated skip column index (optional)
          -h, --help                                  print this message
 
+If you want to do something like below:
+
+    use strict; use warnings;
+    use Text::CSV::Pivot;
+
+    Text::CSV::Pivot->new({ input_file    => 'sample.csv',
+                            col_key_idx   => 0,
+                            col_name_idx  => 1,
+                            col_value_idx => 2,
+                            col_skip_idx  => [3] })->transform;
+
+Then this can be achieved using CLI C<csv-pivot> like below:
+
+    $ cvs-pivot -i sample.csv -k 0 -n 1 -v 2 -s 3
+
 =head1 CONSTRUCTOR
 
 The following table explains the parameters for the constructor. However you can
